@@ -18,8 +18,11 @@
 """
 
 import logging
-
+import sys
+from .version import version
 
 class Settings:
     logLevel = logging.INFO
-    requestTimeoutSeconds = 30
\ No newline at end of file
+    logPath  = "smartling-api-sdk-python.log"
+    requestTimeoutSeconds = 30
+    userAgent = "Python SDK client v%s py:%s" % (version, sys.version.split()[0])
