@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 
-''' Copyright 2013 Smartling, Inc.
+""" Copyright 2012-2021 Smartling, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this work except in compliance with the License.
@@ -15,23 +15,24 @@
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
-'''
+"""
+
 
 class SmartlingDirective:
     """ Smartling directive which is used for file upload """
-    sl_prefix = "smartling."
+    SL_PREFIX = "smartling."
 
     def __init__(self, name, value):
         if not name:
             raise Exception("name cannot be empty!")
-        self.name = self.__remove_sl_prefix(name.lower())
+        self.name = self.__unPrefix(name.lower())
 
         if value is None:
             self.value = ""
         else:
             self.value = value
 
-    def __remove_sl_prefix(self, name):
-        if name.startswith(self.sl_prefix):
-            return name[len(self.sl_prefix):]
+    def __unPrefix(self, name):
+        if name.startswith(self.SL_PREFIX):
+            return name[len(self.SL_PREFIX):]
         return name
